summaryrefslogtreecommitdiff
path: root/src/library
diff options
context:
space:
mode:
authorPaul Phillips <paulp@improving.org>2012-01-14 10:59:53 -0800
committerPaul Phillips <paulp@improving.org>2012-01-14 10:59:53 -0800
commit964fc6ee55dec031b5d697114db84a365425baf8 (patch)
treedf3921df29e61a57b45373d3a8b3006d94280a60 /src/library
parent8c5583c1a229fc18fdef818649d4db793c0989a5 (diff)
downloadscala-964fc6ee55dec031b5d697114db84a365425baf8.tar.gz
scala-964fc6ee55dec031b5d697114db84a365425baf8.tar.bz2
scala-964fc6ee55dec031b5d697114db84a365425baf8.zip
Toward the elimination of setInternalFlags.
Modifications in LiftCode to avoid upsetting the happy world upon which I am converging where flags change in an almost predictable fashion.
Diffstat (limited to 'src/library')
-rwxr-xr-xsrc/library/scala/reflect/api/Symbols.scala4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/library/scala/reflect/api/Symbols.scala b/src/library/scala/reflect/api/Symbols.scala
index 31bcdebe7e..8b4b170847 100755
--- a/src/library/scala/reflect/api/Symbols.scala
+++ b/src/library/scala/reflect/api/Symbols.scala
@@ -150,10 +150,10 @@ trait Symbols { self: Universe =>
*/
def asTypeIn(site: Type): Type
/** A fresh symbol with given position `pos` and name `name` that has
* the current symbol as its owner.
*/
- def newNestedSymbol(pos: Position, name: Name): Symbol // needed by LiftCode
+ def newNestedSymbol(name: Name, pos: Position, flags: Long): Symbol // needed by LiftCode
/** Low-level operation to set the symbol's flags
* @return the symbol itself
@@ -150,10 +150,10 @@ trait Symbols { self: Universe =>
*/
def asTypeIn(site: Type): Type
- /** A fresh symbol with given position `pos` and name `name` that has
+ /** A fresh symbol with given name `name`, position `pos` and flags `flags` that has
* the current symbol as its owner.
*/